@@ -1,8 +1,10 @@
 /* -*- mode: c++; c-basic-offset:4 -*-
     models/keylistmodelinterface.h
 
-    This file is part of Kleopatra, the KDE keymanager
+    This file is part of libkleopatra, the KDE keymanagement library
     SPDX-FileCopyrightText: 2008 Klarälvdalens Datakonsult AB
+    SPDX-FileCopyrightText: 2021 g10 Code GmbH
+    SPDX-FileContributor: Ingo Klöcker <dev@ingo-kloecker.de>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -12,6 +14,8 @@
 
 #include <vector>
 
+#include <kleo_export.h>
+
 namespace GpgME
 {
 class Key;
@@ -22,45 +26,21 @@ template <typename T> class QList;
 
 namespace Kleo
 {
+class KeyGroup;
 
-class KeyListModelInterface
+class KLEO_EXPORT KeyListModelInterface
 {
 public:
-    virtual ~KeyListModelInterface() {}
-
-    static const int FingerprintRole = 0xF1;
-    static const int KeyRole = 0xF2;
-
-    enum Columns {
-        PrettyName,
-        PrettyEMail,
-        ValidFrom,
-        ValidUntil,
-        TechnicalDetails,
-        ShortKeyID,
-        KeyID,
-        Fingerprint,
-        Issuer,
-        SerialNumber,
-        OwnerTrust,
-        Origin,
-        LastUpdate,
-#if 0
-        LongKeyID,
-#endif
-
-        Validity,
-        Summary, // Short summary line
-        Remarks, // Additional remark notations
-        NumColumns,
-        Icon = PrettyName // which column shall the icon be displayed in?
-    };
+    virtual ~KeyListModelInterface();
 
     virtual GpgME::Key key(const QModelIndex &idx) const = 0;
     virtual std::vector<GpgME::Key> keys(const QList<QModelIndex> &idxs) const = 0;
 
     virtual QModelIndex index(const GpgME::Key &key) const = 0;
     virtual QList<QModelIndex> indexes(const std::vector<GpgME::Key> &keys) const = 0;
+
+    virtual KeyGroup group(const QModelIndex &idx) const = 0;
+    virtual QModelIndex index(const KeyGroup &group) const = 0;
 };
 
 }
